#![no_std]
#![no_main]

// We need to use cortex_m here so the linker can find it's critical-section, but we import is as
// an underscore since we don't directly use any of its symbols.
use cortex_m as _;

// The entry import gives us a macro to indicate where the microcontroller should start the
// program, and also sets up the FPU on our Cortex-M4F.
use cortex_m_rt::entry;

// Provides functions that allow printing back to probe-rs.
use panic_rtt_target as _;
use rtt_target::{rprintln, rtt_init_print};

// Start here, and don't ever return from this function.
#[entry]
fn main() -> ! {
    // Initialise our debug printer.
    rtt_init_print!();
    // Send a message back via the debugger.
    rprintln!("Hello, world!");

    // Do nothing, forever.
    loop {}
}
